@@ -26,6 +26,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 #include "gcs-i18n.h"
 #include "Util.h"
 #include <algorithm>
+#include "NPrefsWindow.h"
 
 #ifdef USE_XINERAMA
 #include <X11/extensions/Xinerama.h>
@@ -33,10 +34,10 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
 // leethax constructor
 
-NWindow::NWindow (void) : apply (Gtk::Stock::APPLY), is_multihead(false), is_xinerama(false)  {
+NWindow::NWindow (void) : apply (Gtk::Stock::APPLY), is_multihead(false), is_xinerama(false), btn_prefs(Gtk::Stock::PREFERENCES) {
 	
 	set_border_width (5);
-	set_default_size (350, 500);
+	set_default_size (450, 500);
 
 	main_vbox.set_spacing (5);
 	add (main_vbox);
@@ -51,16 +52,18 @@ NWindow::NWindow (void) : apply (Gtk::Stock::APPLY), is_multihead(false), is_xin
 	bot_hbox.pack_start(button_bgcolor, FALSE, FALSE, 0);
 	
 	bot_hbox.pack_end(apply, FALSE, FALSE, 0);
+    bot_hbox.pack_end(btn_prefs, FALSE, FALSE, 0);
 
 	// add to main box
 	main_vbox.pack_start (view, TRUE, TRUE, 0);
 	main_vbox.pack_start (bot_hbox, FALSE, FALSE, 0);
 
 	// signals
-	view.view.signal_row_activated ().connect (sigc::mem_fun(*this, &NWindow::sighandle_dblclick_item));
+    view.signal_selected.connect(sigc::mem_fun(*this, &NWindow::sighandle_dblclick_item));
 	apply.signal_clicked ().connect (sigc::mem_fun(*this, &NWindow::sighandle_click_apply));
-
-	// set icon
+    btn_prefs.signal_clicked().connect(sigc::mem_fun(*this, &NWindow::sighandle_btn_prefs));
+	
+    // set icon
 	try {
 		Glib::RefPtr<Gtk::IconTheme> icontheme = Gtk::IconTheme::get_default();
 		std::vector<Glib::RefPtr<Gdk::Pixbuf> > vec;
@@ -76,6 +79,7 @@ NWindow::NWindow (void) : apply (Gtk::Stock::APPLY), is_multihead(false), is_xin
 		// don't even worry about it!
 	}
 	
+    m_dirty = false;
 }
 
 // shows all of our widgets
@@ -88,20 +92,23 @@ void NWindow::show (void) {
 	bot_hbox.show ();
 	main_vbox.show ();
 	button_bgcolor.show();
+    btn_prefs.show();
 
 	this->set_title("Nitrogen");
 }
 
 /**
- * Handles the user double clicking on a row in the treeview.  
+ * Handles the user double clicking on a row in the view. 
  */
-void NWindow::sighandle_dblclick_item (const Gtk::TreeModel::Path& path, Gtk::TreeViewColumn * column) {
-	
+void NWindow::sighandle_dblclick_item (const Gtk::TreeModel::Path& path) {
+
 	// find out which image was double clicked
 	Gtk::TreeModel::iterator iter = (view.store)->get_iter(path);
 	Gtk::TreeModel::Row row = *iter;
 	this->set_bg(row[view.record.Filename]);
 
+    // preview - set dirty flag
+    m_dirty = true;
 }
 
 /**
@@ -112,11 +119,14 @@ void NWindow::sighandle_dblclick_item (const Gtk::TreeModel::Path& path, Gtk::Tr
 void NWindow::sighandle_click_apply (void) {
 	
 	// find out which image is currently selected
-	Gtk::TreeModel::iterator iter = view.view.get_selection()->get_selected ();
+	Gtk::TreeModel::iterator iter = view.get_selected ();
 	Gtk::TreeModel::Row row = *iter;
     Glib::ustring file = row[view.record.Filename];
 	this->set_bg(file);
 
+    // apply - remove dirty flag
+    m_dirty = false;
+
     SetBG::SetMode mode = SetBG::string_to_mode( this->select_mode.get_active_data() );
 	Glib::ustring thedisp = this->select_display.get_active_data(); 
 	Gdk::Color bgcolor = this->button_bgcolor.get_color();
@@ -141,6 +151,10 @@ void NWindow::sighandle_click_apply (void) {
 
         std::map<Glib::ustring, Glib::ustring>::iterator mapiter = view.map_setbgs.find(curbgondisp);
 
+        // checking for fullscreen xinerama with several screens end
+        if( mapiter == view.map_setbgs.end() )
+            break;
+
         // if filenames don't match, this row must be blanked out!
         Glib::ustring filename = (*i)[view.record.Filename];
         if (filename != (*mapiter).second)
@@ -152,11 +166,27 @@ void NWindow::sighandle_click_apply (void) {
             (*i)[view.record.Description] = Util::make_current_set_string(this, filename, (*mapiter).first);
     }
 
-    if (!this->is_multihead || thedisp == "xin_-1")
+}
+
+bool NWindow::on_delete_event(GdkEventAny *event)
+{
+    if (m_dirty)
     {
-        hide();
-        Gtk::Main::quit();
+        Gtk::MessageDialog dialog(*this, _("You previewed an image without applying it, exit anyway?"), false, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_YES_NO, true);
+
+        int result = dialog.run();
+        switch (result)
+        {
+            case Gtk::RESPONSE_YES:
+
+                break;
+            case Gtk::RESPONSE_NO:
+                return true;
+                break;
+        };
     }
+
+    return Gtk::Window::on_delete_event(event);
 }
 
 /**
@@ -238,6 +268,7 @@ void NWindow::setup_select_boxes() {
 	}
 
 	this->select_mode.add_image_row( icon, _("Zoomed"), SetBG::mode_to_string(SetBG::SET_ZOOM), false );
+	this->select_mode.add_image_row( icon, _("Zoomed Fill"), SetBG::mode_to_string(SetBG::SET_ZOOM_FILL), false );
 
 	// displays
 	Glib::RefPtr<Gdk::DisplayManager> manager = Gdk::DisplayManager::get();
@@ -360,11 +391,56 @@ void NWindow::set_default_selections()
 		for (Gtk::TreeIter iter = view.store->children().begin(); iter != view.store->children().end(); iter++)
 		{
 			if ( (*iter)[view.record.CurBGOnDisp] == default_selection) {
-				view.view.get_selection()->select(iter);
-				view.view.scroll_to_row(Gtk::TreeModel::Path(iter), 0.5);
+                Glib::signal_timeout().connect(sigc::bind(sigc::mem_fun(view, &Thumbview::select), new Gtk::TreeIter(iter)), 100);
 				break;
 			}
 		}
 	}
 
 }
+
+/////////////////////////////////////////////////////////////////////////////
+
+/**
+ * Handles the preferences button being pressed.
+ * Shows the preferences dialog and updates the view as needed.
+ */
+void NWindow::sighandle_btn_prefs()
+{
+    Config *cfg = Config::get_instance();
+    Config *clone = cfg->clone();
+
+    NPrefsWindow *nw = new NPrefsWindow(*this, clone);
+    int resp = nw->run();
+
+    if (resp == Gtk::RESPONSE_OK)
+    {
+        // figure out what directories to reload and what directories to not reload!
+        // do this before we reload the main config!
+
+        VecStrs vec_load;
+        VecStrs vec_unload;
+
+        VecStrs vec_cfg_dirs = cfg->get_dirs();
+        VecStrs vec_clone_dirs = clone->get_dirs();
+        for (VecStrs::iterator i = vec_cfg_dirs.begin(); i != vec_cfg_dirs.end(); i++)
+            if (find(vec_clone_dirs.begin(), vec_clone_dirs.end(), *i) == vec_clone_dirs.end())
+                vec_unload.push_back(*i);
+
+        for (VecStrs::iterator i = vec_clone_dirs.begin(); i != vec_clone_dirs.end(); i++)
+            if (find(vec_cfg_dirs.begin(), vec_cfg_dirs.end(), *i) == vec_cfg_dirs.end())
+                vec_load.push_back(*i);
+
+        cfg->load_cfg();        // tells the global instance to reload itself from disk, which the prefs dialog
+                                // told our clone to save to
+        view.set_current_display_mode(cfg->get_display_mode());
+
+        for (VecStrs::iterator i = vec_unload.begin(); i != vec_unload.end(); i++)
+            view.unload_dir(*i);
+
+        for (VecStrs::iterator i = vec_load.begin(); i != vec_load.end(); i++)
+            view.load_dir(*i);
+    }
+
+}
+
