@@ -34,7 +34,7 @@ class NWindow : public Gtk::Window {
 		virtual ~NWindow ();
 
 		Thumbview view;
-		void sighandle_dblclick_item(const Gtk::TreeModel::Path& path, Gtk::TreeViewColumn * column);
+		void sighandle_dblclick_item(const Gtk::TreeModel::Path& path);
 		void sighandle_click_apply(void);
 		void sighandle_mode_change(void);
 
@@ -45,7 +45,9 @@ class NWindow : public Gtk::Window {
 		bool is_multihead;
 		bool is_xinerama;
 
-	protected:
+        void set_bg(Glib::ustring file);
+
+	protected:        
 		
 		Gtk::VBox main_vbox;
 		Gtk::HBox bot_hbox;
@@ -53,11 +55,19 @@ class NWindow : public Gtk::Window {
 		ImageCombo select_mode, select_display;
 
 		Gtk::Button apply;
+        Gtk::Button btn_prefs;
 		Gtk::ColorButton button_bgcolor;
 
-		void set_bg(Glib::ustring file);
+        bool m_dirty;       // set if the user double clicks to preview but forgets to press apply
+
 		void setup_select_boxes();
 
+        void sighandle_togb_list_toggled();
+        void sighandle_togb_icon_toggled();
+        void sighandle_btn_prefs();
+
+        virtual bool on_delete_event(GdkEventAny *event);
+
 #ifdef USE_XINERAMA
 		// xinerama stuff
 		XineramaScreenInfo* xinerama_info;
