@@ -254,7 +254,6 @@ bool SetBG::set_bg_xinerama(XineramaScreenInfo* xinerama_info, gint xinerama_num
 	}
 
 	Display *xdisp = GDK_DISPLAY_XDISPLAY(_display->gobj());
-	XSetCloseDownMode(xdisp, RetainPermanent);
 	Window xwin = DefaultRootWindow(xdisp);
 	Pixmap* xoldpm = NULL;
 
@@ -301,6 +300,9 @@ bool SetBG::set_bg_xinerama(XineramaScreenInfo* xinerama_info, gint xinerama_num
 		pixmap = Gdk::Pixmap::create(window,winw,winh,window->get_depth());
         int width, height;
         pixmap->get_size(width, height);
+
+        // only set the mode if we never had an old pixmap to work with
+	    XSetCloseDownMode(xdisp, RetainPermanent);
 	}
 
 	// set the colormap 
@@ -379,6 +381,24 @@ bool SetBG::set_bg_xinerama(XineramaScreenInfo* xinerama_info, gint xinerama_num
 
 #endif
 
+/**
+ * Handles a BadWindow error in get_rootwindowtype.
+ *
+ * This is rather hax, but not sure how else to handle it.
+ */
+int SetBG::handle_x_errors(Display *display, XErrorEvent *error)
+{
+    if (error->error_code == BadWindow)
+        return 0;
+
+    std::cerr << "SetBG::handle_x_errors received an error it cannot handle!\n";
+    std::cerr << "\tcode: " << error->error_code << "\n";
+    std::cerr << "\nWe must abort!";
+    exit(1);
+
+    return 1;
+}
+
 /**
  * Determines if Nautilus is being used to draw the root desktop.
  *
@@ -413,7 +433,11 @@ SetBG::RootWindowType SetBG::get_rootwindowtype(Glib::RefPtr<Gdk::Window> rootwi
     gchar **list;
     gint num;
 
-    if (XGetTextProperty(xdisp, wid, &tprop, propatom) && tprop.nitems)
+    XErrorHandler old_x_error_handler = XSetErrorHandler(SetBG::handle_x_errors);
+    bool bGotText = XGetTextProperty(xdisp, wid, &tprop, propatom);
+    XSetErrorHandler(old_x_error_handler);
+
+    if (bGotText && tprop.nitems)
     {
         if (XTextPropertyToStringList(&tprop, &list, &num))
         {
@@ -469,6 +493,14 @@ bool SetBG::set_bg_nautilus(Glib::RefPtr<Gdk::Screen> screen, Glib::ustring file
     vecCmdLine.push_back(std::string("--set"));
     vecCmdLine.push_back(std::string("/desktop/gnome/background/picture_filename"));
     vecCmdLine.push_back(std::string(file));
+
+    std::string strcolor = std::string( bgcolor.to_string() );
+    vecCmdLine.push_back(std::string("--set"));
+    vecCmdLine.push_back(std::string("/desktop/gnome/background/primary_color"));
+    vecCmdLine.push_back(strcolor);
+    vecCmdLine.push_back(std::string("--set"));
+    vecCmdLine.push_back(std::string("/desktop/gnome/background/secondary_color"));
+    vecCmdLine.push_back(strcolor);
     
     try
     {
