@@ -190,7 +190,10 @@ void Thumbview::add_file(std::string filename, std::string rootdir)
 	Glib::RefPtr<Gdk::Pixbuf> thumb = this->loading_image; 
 	row[record.Thumbnail] = thumb;
 	row[record.Filename] = filename;
-	row[record.Description] = Glib::ustring(filename, filename.rfind ("/")+1);
+
+    int idx = filename.rfind("/");
+	row[record.Description] = Glib::ustring(filename.substr(idx+1));
+
     row[record.RootDir] = rootdir;
 
     for (std::map<Glib::ustring, Glib::ustring>::iterator i = map_setbgs.begin(); i!=map_setbgs.end(); i++)
@@ -529,24 +532,17 @@ void Thumbview::create_cache_images()
 		Glib::ustring file = p->file;
 		Glib::ustring cachefile = this->cache_file(file);
 
-		Util::program_log("create_cache_images(): Caching file %s\n", file.c_str());
+		Util::program_log("create_cache_images(): + Caching file %s\n", file.c_str());
 
-		// open image
+		// open image, scale to smallish 4:3 with aspect preserved
 		try {
-			thumb = Gdk::Pixbuf::create_from_file(file);
+			thumb = Gdk::Pixbuf::create_from_file(file, 100, 75, true);
 		} catch (...) {
 			// forget it, move on
 			delete p;
 			continue;
 		}
 
-		// eliminate zero heights (due to really tiny images :/)
-		int height = (int)(100*((float)thumb->get_height()/(float)thumb->get_width()));
-		if (!height) height = 1;
-
-		// create thumb
-		thumb = thumb->scale_simple(100, height, Gdk::INTERP_TILES);
-
 		// create required fd.o png tags
 		std::list<Glib::ustring> opts, vals;
 		opts.push_back(Glib::ustring("tEXt::Thumb::URI"));
@@ -564,6 +560,8 @@ void Thumbview::create_cache_images()
 				
 		thumb->save(cachefile, "png", opts, vals);
 
+        Util::program_log("create_cache_images(): - Finished caching file %s\n", file.c_str());
+
 		// send it to the display
 		TreePair *sendp = new TreePair();
 		sendp->file = file;
@@ -745,6 +743,8 @@ void Thumbview::file_created_callback(std::string filename) {
 	}
 }
 
+#endif
+
 void Thumbview::set_current_display_mode(DisplayMode newmode)
 {
     remove();
@@ -776,4 +776,4 @@ void Thumbview::sighandle_view_activated(const Gtk::TreePath& path, Gtk::TreeVie
     signal_selected(path);
 }
 
-#endif
+
