@@ -19,6 +19,9 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
 */
 
+#ifndef _THUMBVIEW_H_
+#define _THUMBVIEW_H_
+
 #include "main.h"
 #include <queue>
 #include <errno.h>
@@ -57,8 +60,6 @@ class DelayLoadingStore : public Gtk::ListStore
 	protected:
 		GAsyncQueue *aqueue_loadthumbs;
 		Thumbview *thumbview;
-
-
 };
 
 /////////////////////////////////////////////////////////////////////////////
@@ -77,6 +78,7 @@ class ThumbviewRecord : public Gtk::TreeModelColumnRecord
             add(Time);
             add(LoadingThumb);
             add(CurBGOnDisp);
+            add(RootDir);
         }
 
 		Gtk::TreeModelColumn<Glib::ustring> Filename;
@@ -85,8 +87,16 @@ class ThumbviewRecord : public Gtk::TreeModelColumnRecord
 		Gtk::TreeModelColumn<time_t> Time;
 		Gtk::TreeModelColumn<bool> LoadingThumb;
         Gtk::TreeModelColumn<Glib::ustring> CurBGOnDisp;
+        Gtk::TreeModelColumn<Glib::ustring> RootDir;
 };
 
+/////////////////////////////////////////////////////////////////////////////
+
+enum DisplayMode
+{
+    LIST,
+    ICON
+};
 
 /////////////////////////////////////////////////////////////////////////////
 
@@ -102,10 +112,9 @@ class Thumbview : public Gtk::ScrolledWindow {
 			SORT_RTIME
 		} SortMode;
 		
-		void set_dir(std::string indir) { this->dir = indir; }
-		
 		Glib::RefPtr<DelayLoadingStore> store;
 		Gtk::TreeView view;
+        Gtk::IconView iview;
         ThumbviewRecord record;
 	
 		// dispatcher 
@@ -114,21 +123,47 @@ class Thumbview : public Gtk::ScrolledWindow {
 		// thread/idle funcs
 		void load_cache_images();
 		void create_cache_images();
-		void load_dir(std::string dir = "");
+		void load_dir(std::string dir);
+        void load_dir(const VecStrs& dirs);
+        void unload_dir(std::string dir);
 
 		void set_sort_mode (SortMode mode);
 		// search compare function
 		bool search_compare (const Glib::RefPtr<Gtk::TreeModel>& model, int column, const Glib::ustring& key, const Gtk::TreeModel::iterator& iter);
 
+        bool select(const Gtk::TreeModel::iterator *iter);
+
 		// loading image
 		Glib::RefPtr<Gdk::Pixbuf> loading_image;
 
         // "cache" of config - maps displays to full filenames
         std::map<Glib::ustring, Glib::ustring> map_setbgs;
         void load_map_setbgs();
+
+        DisplayMode m_curmode; 
+
+        void set_current_display_mode(DisplayMode newmode);
+        DisplayMode get_current_display_mode() { return m_curmode; }
+
+        void set_icon_captions(gboolean caps);
+        gboolean get_icon_captions() { return m_icon_captions; }
+
+        Gtk::TreeModel::iterator get_selected();
+        sigc::signal<void, const Gtk::TreePath&> signal_selected;
+
+        const Glib::TimeVal& get_last_loaded_time()
+            { return m_last_loaded_time; }
 	
 	protected:
 
+        Glib::TimeVal m_last_loaded_time;
+
+        void update_last_loaded_time()
+            { m_last_loaded_time.assign_current_time(); }
+
+        void sighandle_iview_activated(const Gtk::TreePath& path);
+        void sighandle_view_activated(const Gtk::TreePath& path, Gtk::TreeViewColumn *column);
+
 #ifdef USE_INOTIFY
 		void file_deleted_callback(std::string filename);
 		void file_changed_callback(std::string filename);
@@ -136,8 +171,10 @@ class Thumbview : public Gtk::ScrolledWindow {
 		std::map<std::string, Inotify::Watch*> watches;
 #endif
 
-		void add_file(std::string filename);
+		void add_file(std::string filename, std::string rootdir);
 		void handle_dispatch_thumb();
+
+        VecStrs m_list_loaded_rootdirs;
 		
 		Gtk::TreeViewColumn *col_thumb;
 		Gtk::TreeViewColumn *col_desc;
@@ -145,18 +182,18 @@ class Thumbview : public Gtk::ScrolledWindow {
 		Gtk::CellRendererPixbuf rend_img;
 		Gtk::CellRendererText rend;
 
+        gboolean m_icon_captions;
+
 		// utility functions
 		bool is_image(std::string file);
 		Glib::ustring cache_file(Glib::ustring file);
 		void update_thumbnail(Glib::ustring file, Gtk::TreeModel::iterator iter, Glib::RefPtr<Gdk::Pixbuf> pb);
 		
-		// base dir
-		// TODO: remove when we get a proper db
-		std::string dir;
-
 		// load thumbnail queue
 		GAsyncQueue* aqueue_loadthumbs;
 		GAsyncQueue* aqueue_createthumbs;
 		GAsyncQueue* aqueue_donethumbs;
 
 };
+
+#endif
