@@ -26,7 +26,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 #include "ArgParser.h"
 #include "Util.h"
 //#include "gettext.h"
-//#include <inti/i18n.h> 
+//#include <inti/i18n.h>
 #include "gcs-i18n.h"
 
 void restore_bgs()
@@ -38,13 +38,10 @@ void restore_bgs()
 	Util::program_log("leaving restore_bgs()");
 }
 
-void set_bg_once(Glib::ustring file, SetBG::SetMode mode, bool save)
+void set_bg_once(Glib::ustring file, SetBG::SetMode mode, bool save, Gdk::Color col)
 {
 	Util::program_log("entering set_bg_once()");
 
-	// TODO: how to get a default color in here
-	Gdk::Color col;
-
 	// TODO: find out why teh config::set_bg will not get me default
 	Glib::ustring disp;
 
@@ -56,6 +53,20 @@ void set_bg_once(Glib::ustring file, SetBG::SetMode mode, bool save)
 	Util::program_log("leaving set_bg_once()");
 }
 
+bool on_window_close_save_pos(GdkEventAny* event, Gtk::Window *window)
+{
+   	Config *cfg = Config::get_instance();
+    int x, y;
+    window->get_position(x, y);
+    cfg->set_pos(x, y);
+
+    int w, h;
+    window->get_size(w, h);
+    cfg->set_size(w, h);
+
+    return false; 
+}
+
 #ifdef USE_INOTIFY
 bool poll_inotify(void) {
 	Inotify::Watch::poll(0);
@@ -77,7 +88,7 @@ int main (int argc, char ** argv) {
 	Gtk::Main kit(argc, argv);
 	Gtk::IconTheme::get_default()->append_search_path(NITROGEN_DATA_DIR
 													  G_DIR_SEPARATOR_S "icons");
-	Glib::thread_init();
+	if (!Glib::thread_supported()) Glib::thread_init();
 	Config *cfg = Config::get_instance();
 	ArgParser *parser = Util::create_arg_parser();
 
@@ -101,40 +112,78 @@ int main (int argc, char ** argv) {
 
 	// get the starting dir
 	std::string startdir = parser->get_extra_args();
-	if (startdir.length() <= 0) {
-		startdir = ".";
-        cfg->set_recurse(false);
-	}
-	startdir = Util::fix_start_dir(std::string(startdir));
+    bool bcmdlinedir = startdir.length() > 0;
+//	if (!bcmd <= 0) {
+//		startdir = ".";
+//        cfg->set_recurse(false);
+//	}
+    if (bcmdlinedir)
+    	startdir = Util::fix_start_dir(std::string(startdir));
 	
 	// should we set on the command line?
+    Gdk::Color color("#000000");
+    if ( parser->has_argument("set-color") ) {
+        Glib::ustring bgcolor_str = parser->get_value ("set-color");
+        color.parse(bgcolor_str);
+    }
+
 	if ( parser->has_argument("set-tiled") )	{
-		set_bg_once(startdir, SetBG::SET_TILE, parser->has_argument("save"));
+		set_bg_once(startdir, SetBG::SET_TILE, parser->has_argument("save"), color);
 		return 0;
 	}
 
 	if ( parser->has_argument("set-scaled") )	{
-		set_bg_once(startdir, SetBG::SET_SCALE, parser->has_argument("save"));
+		set_bg_once(startdir, SetBG::SET_SCALE, parser->has_argument("save"), color);
+		return 0;
+	}
+
+    if ( parser->has_argument("set-auto") )	{
+		set_bg_once(startdir, SetBG::SET_AUTO, parser->has_argument("save"), color);
 		return 0;
 	}
 
 	if ( parser->has_argument("set-zoom") )	{
-		set_bg_once(startdir, SetBG::SET_ZOOM, parser->has_argument("save"));
+		set_bg_once(startdir, SetBG::SET_ZOOM, parser->has_argument("save"), color);
+		return 0;
+	}
+
+	if ( parser->has_argument("set-zoom-fill") )	{
+		set_bg_once(startdir, SetBG::SET_ZOOM_FILL, parser->has_argument("save"), color);
 		return 0;
 	}
 
 	if ( parser->has_argument("set-centered") )	{
-		set_bg_once(startdir, SetBG::SET_CENTER, parser->has_argument("save"));
+		set_bg_once(startdir, SetBG::SET_CENTER, parser->has_argument("save"), color);
 		return 0;
 	}
 
 	if ( parser->has_argument("no-recurse") ) 
 		cfg->set_recurse(false);
-	
+
+    // load configuration if there is one
+    cfg->load_cfg();
+
+    guint w, h;
+    cfg->get_size(w, h);
+
+    gint x, y;
+    cfg->get_pos(x, y);
+
+    // create main window
 	NWindow* main_window = new NWindow();
-	main_window->view.set_dir(startdir);
-	main_window->view.load_dir();
+    main_window->set_default_size(w, h);
+    main_window->move(x, y);                    // most likely will be ignored by the wm
+
+//	main_window->view.set_dir(startdir);
+    if (bcmdlinedir)
+    	main_window->view.load_dir(startdir);
+    else
+        main_window->view.load_dir(cfg->get_dirs());
+
+    main_window->view.set_current_display_mode(cfg->get_display_mode());
 	main_window->set_default_selections();
+    main_window->view.set_icon_captions(cfg->get_icon_captions());
+    main_window->signal_delete_event().connect(sigc::bind(sigc::ptr_fun(&on_window_close_save_pos), main_window));
 	main_window->show();
 
 	if ( parser->has_argument("sort") ) {
@@ -167,5 +216,7 @@ int main (int argc, char ** argv) {
 
 	Gtk::Main::run (*main_window);
 
+    cfg->save_cfg();
+
 	return 0;
 }
